import { ElementRef, AfterViewInit, QueryList, OnDestroy } from '@angular/core';
import { ICalendarDate } from './calendar';
import { IgxMonthPickerBaseDirective } from './month-picker-base';
import { IgxMonthsViewComponent } from './months-view/months-view.component';
import { IgxYearsViewComponent } from './years-view/years-view.component';
import { IgxDaysViewComponent } from './days-view/days-view.component';
import { IViewChangingEventArgs } from './days-view/days-view.interface';
/**
 * **Ignite UI for Angular Calendar** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/calendar.html)
 *
 * The Ignite UI Calendar provides an easy way to display a calendar and allow users to select dates using single, multiple
 * or range selection.
 *
 * Example:
 * ```html
 * <igx-calendar selection="range"></igx-calendar>
 * ```
 */
export declare class IgxCalendarComponent extends IgxMonthPickerBaseDirective implements AfterViewInit, OnDestroy {
    /**
     * Sets/gets the `id` of the calendar.
     * If not set, the `id` will have value `"igx-calendar-0"`.
     * ```html
     * <igx-calendar id = "my-first-calendar"></igx-calendar>
     * ```
     * ```typescript
     * let calendarId =  this.calendar.id;
     * ```
     * @memberof IgxCalendarComponent
     */
    id: string;
    hasHeader: boolean;
    /**
     * Sets/gets whether the calendar header will be in vertical position.
     * Default value is `false`.
     * ```html
     * <igx-calendar [vertical] = "true"></igx-calendar>
     * ```
     * ```typescript
     * let isVertical = this.calendar.vertical;
     * ```
     */
    vertical: boolean;
    /**
     * Sets/gets the number of month views displayed.
     * Default value is `1`.
     * ```html
     * <igx-calendar [vertical] = "true" [monthsViewNumber]="2"></igx-calendar>
     * ```
     * ```typescript
     * let monthViewsDisplayed = this.calendar.monthsViewNumber;
     * ```
     */
    get monthsViewNumber(): number;
    set monthsViewNumber(val: number);
    /**
     * @hidden
     */
    animationAction: any;
    /**
     * @hidden
     */
    nextDate: Date;
    /**
     * @hidden
     */
    isKeydownTrigger: boolean;
    /**
     * @hidden
     */
    callback: (next: any) => void;
    /**
     * The default `tabindex` attribute for the component.
     *
     * @hidden
     */
    tabindex: number;
    /**
     * The default aria role attribute for the component.
     *
     * @hidden
     */
    role: string;
    /**
     * The default aria lebelled by attribute for the component.
     *
     * @hidden
     */
    ariaLabelledBy: string;
    /**
     * The default css class applied to the component.
     *
     * @hidden
     */
    get styleVerticalClass(): boolean;
    /**
     * The default css class applied to the component.
     *
     * @hidden
     */
    styleClass: boolean;
    /**
     * @hidden
     */
    monthsView: IgxMonthsViewComponent;
    /**
     * @hidden
     */
    monthsBtn: ElementRef;
    /**
     * @hidden
     */
    dacadeView: IgxYearsViewComponent;
    /**
     * @hidden
     */
    daysView: IgxDaysViewComponent;
    /**
     * @hidden
     */
    monthViews: QueryList<IgxDaysViewComponent>;
    /**
     * @hidden
     */
    prevMonthBtn: ElementRef;
    /**
     * @hidden
     */
    nextMonthBtn: ElementRef;
    /**
     * @hidden
     */
    get isYearView(): boolean;
    /**
     * Gets the header template.
     * ```typescript
     * let headerTemplate =  this.calendar.headerTeamplate;
     * ```
     * @memberof IgxCalendarComponent
     */
    get headerTemplate(): any;
    /**
     * Sets the header template.
     * ```html
     * <igx-calendar headerTemplateDirective = "igxCalendarHeader"></igx-calendar>
     * ```
     * @memberof IgxCalendarComponent
     */
    set headerTemplate(directive: any);
    /**
     * Gets the subheader template.
     * ```typescript
     * let subheaderTemplate = this.calendar.subheaderTemplate;
     * ```
     */
    get subheaderTemplate(): any;
    /**
     * Sets the subheader template.
     * ```html
     * <igx-calendar subheaderTemplate = "igxCalendarSubheader"></igx-calendar>
     * ```
     * @memberof IgxCalendarComponent
     */
    set subheaderTemplate(directive: any);
    /**
     * Gets the context for the template marked with the `igxCalendarHeader` directive.
     * ```typescript
     * let headerContext =  this.calendar.headerContext;
     * ```
     */
    get headerContext(): {
        $implicit: {
            date: Date;
            full: string;
            index: number;
            monthView: () => void;
            yearView: () => void;
        };
    };
    /**
     * Gets the context for the template marked with either `igxCalendarSubHeaderMonth`
     * or `igxCalendarSubHeaderYear` directive.
     * ```typescript
     * let context =  this.calendar.context;
     * ```
     */
    get context(): {
        $implicit: {
            date: Date;
            full: string;
            index: number;
            monthView: () => void;
            yearView: () => void;
        };
    };
    /**
     * @hidden
     */
    get headerDate(): Date;
    /**
     * @hidden
     */
    private headerTemplateDirective;
    /**
     * @hidden
     */
    private subheaderTemplateDirective;
    /**
     *@hidden
     */
    private _monthsViewNumber;
    /**
     *@hidden
     */
    private _monthViewsChanges$;
    /**
     *@hidden
     */
    private defaultDayView;
    /**
     *@hidden
     */
    dayViews: {
        value: Date | Date[];
        viewDate: Date;
    }[];
    ngAfterViewInit(): void;
    /**
     * Returns the locale representation of the month in the month view if enabled,
     * otherwise returns the default `Date.getMonth()` value.
     *
     * @hidden
     */
    formattedMonth(value: Date): string;
    /**
     * @hidden
     */
    previousMonth(isKeydownTrigger?: boolean): void;
    /**
     * @hidden
     */
    nextMonth(isKeydownTrigger?: boolean): void;
    /**
     * @hidden
     */
    startPrevMonthScroll: (isKeydownTrigger?: boolean) => void;
    /**
     * @hidden
     */
    startNextMonthScroll: (isKeydownTrigger?: boolean) => void;
    /**
     * @hidden
     */
    stopMonthScroll: (event: any) => void;
    /**
     * @hidden
     */
    activeViewDecade(args: Date): void;
    /**
     * @hidden
     */
    activeViewDecadeKB(event: any, args: Date): void;
    /**
     * @hidden
     */
    getFormattedDate(): {
        weekday: string;
        monthday: string;
    };
    /**
     * @hidden
     */
    childClicked(instance: ICalendarDate): void;
    /**
     * @hidden
     */
    viewChanging(args: IViewChangingEventArgs): void;
    /**
     * @hidden
     */
    changeMonth(event: Date): void;
    /**
     * @hidden
     */
    activeViewYear(args: Date, event: any): void;
    private focusMonth;
    /**
     * @hidden
     */
    activeViewYearKB(args: Date, event: any): void;
    /**
     * Deselects date(s) (based on the selection type).
     *```typescript
     * this.calendar.deselectDate(new Date(`2018-06-12`));
     *````
     */
    deselectDate(value?: Date | Date[]): void;
    /**
     * Helper method that does deselection for all month views when selection is "multi"
     * If not called, selection in other month views stays
     * @hidden
     */
    private deselectDateInMonthViews;
    /**
     * @hidden
     */
    getViewDate(i: number): Date;
    /**
     * @hidden
     */
    getMonth(i: number): number;
    /**
     * @hidden
     */
    getContext(i: number): {
        $implicit: {
            date: Date;
            full: string;
            index: number;
            monthView: () => void;
            yearView: () => void;
        };
    };
    /**
     * @hidden
     */
    animationDone(event: any): void;
    /**
     * @hidden
     */
    onKeydownPageDown(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownShiftPageUp(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownHome(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onKeydownEnd(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    onMouseUp(event: KeyboardEvent): void;
    /**
     * @hidden
     */
    ngOnDestroy(): void;
    /**
     * Helper method building and returning the context object inside
     * the calendar templates.
     * @hidden
     */
    private generateContext;
    /**
     * Helper method that sets references for prev/next months for each month in the view
     * @hidden
     */
    private setSiblingMonths;
    /**
     * Helper method returning previous/next day views
     * @hidden
     */
    private getMonthView;
}
